@@ -24,8 +24,11 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 ###############################################################################
-# $Id: PCSC.pm,v 1.6 2001/10/10 13:12:31 lvictor Exp $
+# $Id: PCSC.pm,v 1.7 2002/03/05 14:50:19 rousseau Exp $
 # $Log: PCSC.pm,v $
+# Revision 1.7  2002/03/05 14:50:19  rousseau
+# correctly test if a digit is hexa or not
+#
 # Revision 1.6  2001/10/10 13:12:31  lvictor
 # Added fake variable declarations/initialization to work with make test
 #
@@ -76,7 +79,7 @@ use vars       qw($VERSION @ISA @EXPORT);
 @EXPORT = qw(
 
 );
-$VERSION = '1.0.8';
+$VERSION = '0.01';
 
 bootstrap PCSC $VERSION;
 
@@ -111,7 +114,7 @@ sub ascii_to_array {
 	confess ('usage PCSC::ascii_to_array($string)') unless defined $ascii_string;
 
 	foreach $tmpVal (split / /, $ascii_string) {
-		croak ("ascii_to_array: wrong value ($tmpVal)") unless $tmpVal =~ /[0-9a-fA-F][0-9a-fA-F]*/;
+		croak ("ascii_to_array: wrong value ($tmpVal)") unless ($tmpVal =~ m/[0-9a-f][0-9a-f]/i);
 		push @return_array, hex ($tmpVal);
 	}
 
