@@ -8,10 +8,8 @@
  *    
  *    Copyright (C) 2001 - Lionel VICTOR
  *
- *    This program is free software; you can redistribute it and/or
- *    modify
- *    it under the terms of the GNU General Public License as published
- *    by
+ *    This program is free software; you can redistribute it and/or modify
+ *    it under the terms of the GNU General Public License as published by
  *    the Free Software Foundation; either version 2 of the License, or
  *    (at your option) any later version.
  *
@@ -24,16 +22,21 @@
  *    along with this program; if not, write to the Free Software
  *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
  *    02111-1307 USA
+ *
  *******************************************************************************
- * $Id: PCSCperl.h,v 1.2 2001/06/12 13:41:38 giraud Exp $
+ *
+ * $Id: PCSCperl.h,v 1.3 2002/03/06 08:05:25 rousseau Exp $
+ *
  * $Log: PCSCperl.h,v $
+ * Revision 1.3  2002/03/06 08:05:25  rousseau
+ * comment unused variable declarations
+ *
  * Revision 1.2  2001/06/12 13:41:38  giraud
  * Added support for MacOS X
  *
  * Revision 1.1.1.1  2001/05/31 10:00:30  lvictor
  * Initial import
  *
- *
  */
 
 /******************************************************************************
@@ -161,9 +164,9 @@ LONG SCardListReaderGroups( SCARDCONTEXT, LPSTR, LPDWORD );
 */
 
 /* Declares a variable for any imported variable */
-static LPSCARD_IO_REQUEST gpioSCardT0Pci;
+/* static LPSCARD_IO_REQUEST gpioSCardT0Pci;
 static LPSCARD_IO_REQUEST gpioSCardT1Pci;
-static LPSCARD_IO_REQUEST gpioSCardRawPci;
+static LPSCARD_IO_REQUEST gpioSCardRawPci; */
 
 /* Declares a variable for any imported function */
 static TSCardEstablishContext hEstablishContext = NULL;
@@ -197,3 +200,4 @@ TSCardListReaderGroups hListReaderGroups = NULL;
 #endif
 
 /* End of File */
+
